@@ -53,6 +53,7 @@ CForestModel <- function(
     response_types = c("factor", "numeric", "Surv"),
     weights = TRUE,
     predictor_encoding = "model.frame",
+    na.rm = "response",
     params = new_params(environment()),
 
     gridinfo = new_gridinfo(
@@ -63,8 +64,10 @@ CForestModel <- function(
     ),
 
     fit = function(formula, data, weights, ...) {
-      party::cforest(formula, data = as.data.frame(formula, data),
-                     weights = weights, controls = party::cforest_control(...))
+      party::cforest(
+        formula, data = as.data.frame(formula, data), weights = weights,
+        controls = party::cforest_control(...)
+      )
     },
 
     predict = function(object, newdata, .MachineShop, ...) {
